@@ -1,44 +1,49 @@
 import logging
 import collections
-from typing import Callable
 from paho.mqtt.client import Client, MQTT_ERR_SUCCESS
-from signalsdk.signal_exception import SignalAppLocalMqttEventCallBackError, \
-SignalAppLocalMqttOnConnectionCallBackError, SignalAppLocalMqttOConnectionError, \
-SignalAppLocalMqttPublishError, SignalAppLocalMqttSubscribeError
-OnEventReceived=Callable[[str], None]
+from signalsdk.signal_exception import SignalAppLocalMqttOnConnectionCallBackError, \
+    SignalAppLocalMqttOConnectionError, \
+    SignalAppLocalMqttPublishError, \
+    SignalAppLocalMqttSubscribeError
 
 LOCAL_MQTT_URL = "localhost"
 LOCAL_MQTT_PORT = 1883
 class LocalMqtt():
     def __init__(self, client_id=""):
         self.mqtt_client = Client("localmqtt" + client_id)
+        # topic -> set of callbacks
         self.event_call_backs = collections.defaultdict(set)
         self.subscribed_topic = None
         self.connected_callback = None
 
     def set_on_event_received(self, topic, callback):
+        # add a callback for a topic
         self.event_call_backs[topic].add(callback)
+        logging.debug(f"set_on_event_received=> topic: {topic}, callback: {callback}")
 
     def remove_event_callbacks(self, topic):
+        # remove all callbacks for a topic
         if topic in self.event_call_backs:
-            del self.event_call_backs[topic]
+            self.event_call_backs.pop(topic)
+
+    def set_on_connected(self, callback):
+        self.connected_callback = callback
 
     def on_message_received(self, client, userdata, message):
         payload = str(message.payload.decode("utf-8"))
         topic = message.topic
-        logging.info(f"{__name__}: signalsdk: message received topic:{topic} payload:{payload}")
+        logging.debug(f"{__name__}: signalsdk: message received topic:{topic} payload:{payload}")
         try:
             if topic in self.event_call_backs:
-                logging.info(f"{__name__}: signalsdk: calling event callbacks for topic: {topic}")
                 for callback in self.event_call_backs[topic]:
-                    logging.info(f"{__name__}: signalsdk: calling event "
+                    logging.debug(f"{__name__}: signalsdk: calling event "
                                  f"callback: {callback} and payload: {payload}")
                     callback(payload)
             else:
                 logging.info(f"{__name__}: signalsdk: no callback for topic:{topic}")
         except Exception as e:
             logging.info(f"{__name__}: signalsdk: on_message_received callback error: {e}")
-            raise SignalAppLocalMqttEventCallBackError from e
+            raise e
 
     def on_connect(self, client, userdata, flags, rc):
         logging.info(f"{__name__}: signalsdk::Local MQTT connection established")
@@ -54,11 +59,9 @@ class LocalMqtt():
     def get_client(self):
         return self.mqtt_client
 
-    def connect(self, callback):
-        logging.info(f"{__name__}: signalsdk: connect...")
+    def connect(self):
         self.mqtt_client.on_message=self.on_message_received
         self.mqtt_client.on_disconnect = self.on_disconnect
-        self.connected_callback = callback
         self.mqtt_client.on_connect = self.on_connect
         try:
             self.mqtt_client.connect(LOCAL_MQTT_URL, LOCAL_MQTT_PORT)
